[SCM] Samba Shared Repository - branch v3-4-test updated - release-4-0-0alpha7-844-gb59f79f

2009-04-30 Thread Karolin Seeger
The branch, v3-4-test has been updated
   via  b59f79fd262b9dbb97db90e8cafe7642fd6b6317 (commit)
  from  83c7d8697a8df92ff1592af9c382f483354eeb0f (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-test


- Log -
commit b59f79fd262b9dbb97db90e8cafe7642fd6b6317
Author: Karolin Seeger ksee...@samba.org
Date:   Thu Apr 30 09:27:43 2009 +0200

WHATSNEW: Add some WHATSNEW improvements.

Karolin

---

Summary of changes:
 WHATSNEW.txt |   62 +-
 1 files changed, 61 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/WHATSNEW.txt b/WHATSNEW.txt
index 14c4f53..09cd9a8 100644
--- a/WHATSNEW.txt
+++ b/WHATSNEW.txt
@@ -30,6 +30,7 @@ o The remaining hand-marshalled DCE/RPC services (ntsvcs, 
svcctl, eventlog
 o Samba3 and Samba4 do now share a common tevent library.
 o The code has been cleaned up and the major basic interfaces are shared with
   Samba4 now.
+o An asynchronous API has been added.
 
 
 General Changes
@@ -95,6 +96,8 @@ interfaces now. That is why the libraries were moved to the 
toplevel directory.
 That is one of the first steps to share code and minimize the gap between
 these two versions.
 
+An asynchronous API has been added.
+
 
 ##
 Changes
@@ -105,6 +108,7 @@ smb.conf changes
 
Parameter Name  Description Default
--  --- ---
+
access based share enumNew No
dedicated keytab file  New 
kerberos methodNew default
@@ -117,7 +121,63 @@ smb.conf changes
 New [sub]commands
 -
 
-   net eventlog
+   net eventlogTool to import/dump/export native win32 
eventlog files.
+
+
+New configure options
+-
+
+--enable-external-libtallocEnable external talloc
+--enable-merged-build  Build Samba 4 as well
+--enable-gnutlsTurn on gnutls support
+--with-statedir=DIRWhere to put persistent state files
+--with-cachedir=DIRWhere to put temporary cache files
+--with-ncalprcdir=DIR  Where to put ncalrpc sockets
+--with-selftest-shrdir=DIR The share directory that make test will be run
+   against
+--with-selftest-custom-conf=PATH
+   An optional custom smb.conf that is included in
+   the server smb.conf during make test
+--with-wbclientUse external wbclient
+--with-included-popt   Use bundled popt library, not from system
+--with-libiconv=BASEDIRUse libiconv in BASEDIR/lib and 
BASEDIR/include
+--with-sqlite3 SQLITE3 backend support
+--with-pthreadsInclude pthreads
+--with-setproctitleSearch for setproctitle support
+
+
+Commit Highlights
+=
+
+
+o   Steven Danneman steven.danne...@isilon.com
+* Change the way smbd handles untrusted domain names given during user
+  authentication.
+
+
+o   Guenther Deschner g...@samba.org
+* Replace the hand-marshalled DCE/RPC services ntsvcs, svcctl, eventlog
+  and spoolss by autogenerated code based on PIDL.
+* Fix several printing issues and improve support for printer change
+  notificiations.
+* Add 'net eventlog'.
+
+
+o   Volker Lendecke v...@samba.org
+* Add asynchronous API.
+
+
+o   Stefan Metzmacher me...@samba.org
+* Make Samba3 and Samba4 share a tevent library.
+
+
+o   Dan Sledz dsl...@isilon.com
+* Add two new parameters to control how we verify kerberos tickets.
+
+
+o   Jelmer Vernooij jel...@samba.org
+* Make merged build possible.
+* Move common libraries to the shared lib/ directory.
 
 
 ##


-- 
Samba Shared Repository


[SCM] CTDB repository - branch master updated - ctdb-1.0.79-13-g9434330

2009-04-30 Thread Ronnie Sahlberg
The branch, master has been updated
   via  94343309992929a592348c936e09a7b4f8b512c1 (commit)
  from  bf8dae63d10498e6b6179bbacdd72f1ff0fc60be (commit)

http://gitweb.samba.org/?p=sahlberg/ctdb.git;a=shortlog;h=master


- Log -
commit 94343309992929a592348c936e09a7b4f8b512c1
Author: Ronnie Sahlberg ronniesahlb...@gmail.com
Date:   Thu Apr 30 17:38:30 2009 +1000

dont unconditionally kill/restart ctdb when given service ctdb start   
only start ctdb if it is not already running,   and print an error message 
othervise

---

Summary of changes:
 config/ctdb.init |8 +++-
 1 files changed, 7 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/config/ctdb.init b/config/ctdb.init
index 0903c91..a45babf 100755
--- a/config/ctdb.init
+++ b/config/ctdb.init
@@ -95,9 +95,15 @@ set_retval() {
 }
 
 start() {
-killall -q ctdbd
echo -n $Starting ctdbd service: 
 
+   ctdb ping  /dev/null
+   if [ $? == 0 ] ; then
+   echo $CTDB is already running
+   RETVAL=1
+   return $RETVAL
+fi
+
# check all persistent databases that they look ok
PERSISTENT_DB_DIR=/var/ctdb/persistent
[ -z $CTDB_DBDIR ] || {


-- 
CTDB repository


[SCM] Samba Shared Repository - branch v3-4-test updated - release-4-0-0alpha7-845-gb7c4a63

2009-04-30 Thread Karolin Seeger
The branch, v3-4-test has been updated
   via  b7c4a63d034f8c33b3a4857cae41270bd55e270f (commit)
  from  b59f79fd262b9dbb97db90e8cafe7642fd6b6317 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-test


- Log -
commit b7c4a63d034f8c33b3a4857cae41270bd55e270f
Author: Karolin Seeger ksee...@samba.org
Date:   Thu Apr 30 09:33:43 2009 +0200

WHATSNEW: Add new net service subcommands to the WHATSNEW.

Karolin

---

Summary of changes:
 WHATSNEW.txt |8 +++-
 1 files changed, 7 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/WHATSNEW.txt b/WHATSNEW.txt
index 09cd9a8..64ffe3f 100644
--- a/WHATSNEW.txt
+++ b/WHATSNEW.txt
@@ -121,7 +121,9 @@ smb.conf changes
 New [sub]commands
 -
 
-   net eventlogTool to import/dump/export native win32 
eventlog files.
+   net eventlogImport/dump/export native win32 
eventlog files.
+   net rpc service create  Create a new service.
+   net rpc service delete  Delete an existing service.
 
 
 New configure options
@@ -175,6 +177,10 @@ o   Dan Sledz dsl...@isilon.com
 * Add two new parameters to control how we verify kerberos tickets.
 
 
+o   Danny Tylman danny.tyl...@insightix.com
+* Add 'net rpc service' subcommands 'create' and 'delete'.
+
+
 o   Jelmer Vernooij jel...@samba.org
 * Make merged build possible.
 * Move common libraries to the shared lib/ directory.


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-4-stable updated - release-4-0-0alpha7-842-g2118880

2009-04-30 Thread Karolin Seeger
The branch, v3-4-stable has been updated
   via  21188807b56319b3eca0d410d3859fa5cdbede54 (commit)
   via  c21b12544c7b62a220f9b8fdb1a77bcc0585ed4e (commit)
  from  f2db08fca586f626646653855171c45c30be7933 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-stable


- Log -
commit 21188807b56319b3eca0d410d3859fa5cdbede54
Author: Karolin Seeger ksee...@samba.org
Date:   Thu Apr 30 09:33:43 2009 +0200

WHATSNEW: Add new net service subcommands to the WHATSNEW.

Karolin
(cherry picked from commit b7c4a63d034f8c33b3a4857cae41270bd55e270f)

commit c21b12544c7b62a220f9b8fdb1a77bcc0585ed4e
Author: Karolin Seeger ksee...@samba.org
Date:   Thu Apr 30 09:27:43 2009 +0200

WHATSNEW: Add some WHATSNEW improvements.

Karolin
(cherry picked from commit b59f79fd262b9dbb97db90e8cafe7642fd6b6317)

---

Summary of changes:
 WHATSNEW.txt |   68 +-
 1 files changed, 67 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/WHATSNEW.txt b/WHATSNEW.txt
index 14c4f53..64ffe3f 100644
--- a/WHATSNEW.txt
+++ b/WHATSNEW.txt
@@ -30,6 +30,7 @@ o The remaining hand-marshalled DCE/RPC services (ntsvcs, 
svcctl, eventlog
 o Samba3 and Samba4 do now share a common tevent library.
 o The code has been cleaned up and the major basic interfaces are shared with
   Samba4 now.
+o An asynchronous API has been added.
 
 
 General Changes
@@ -95,6 +96,8 @@ interfaces now. That is why the libraries were moved to the 
toplevel directory.
 That is one of the first steps to share code and minimize the gap between
 these two versions.
 
+An asynchronous API has been added.
+
 
 ##
 Changes
@@ -105,6 +108,7 @@ smb.conf changes
 
Parameter Name  Description Default
--  --- ---
+
access based share enumNew No
dedicated keytab file  New 
kerberos methodNew default
@@ -117,7 +121,69 @@ smb.conf changes
 New [sub]commands
 -
 
-   net eventlog
+   net eventlogImport/dump/export native win32 
eventlog files.
+   net rpc service create  Create a new service.
+   net rpc service delete  Delete an existing service.
+
+
+New configure options
+-
+
+--enable-external-libtallocEnable external talloc
+--enable-merged-build  Build Samba 4 as well
+--enable-gnutlsTurn on gnutls support
+--with-statedir=DIRWhere to put persistent state files
+--with-cachedir=DIRWhere to put temporary cache files
+--with-ncalprcdir=DIR  Where to put ncalrpc sockets
+--with-selftest-shrdir=DIR The share directory that make test will be run
+   against
+--with-selftest-custom-conf=PATH
+   An optional custom smb.conf that is included in
+   the server smb.conf during make test
+--with-wbclientUse external wbclient
+--with-included-popt   Use bundled popt library, not from system
+--with-libiconv=BASEDIRUse libiconv in BASEDIR/lib and 
BASEDIR/include
+--with-sqlite3 SQLITE3 backend support
+--with-pthreadsInclude pthreads
+--with-setproctitleSearch for setproctitle support
+
+
+Commit Highlights
+=
+
+
+o   Steven Danneman steven.danne...@isilon.com
+* Change the way smbd handles untrusted domain names given during user
+  authentication.
+
+
+o   Guenther Deschner g...@samba.org
+* Replace the hand-marshalled DCE/RPC services ntsvcs, svcctl, eventlog
+  and spoolss by autogenerated code based on PIDL.
+* Fix several printing issues and improve support for printer change
+  notificiations.
+* Add 'net eventlog'.
+
+
+o   Volker Lendecke v...@samba.org
+* Add asynchronous API.
+
+
+o   Stefan Metzmacher me...@samba.org
+* Make Samba3 and Samba4 share a tevent library.
+
+
+o   Dan Sledz dsl...@isilon.com
+* Add two new parameters to control how we verify kerberos tickets.
+
+
+o   Danny Tylman danny.tyl...@insightix.com
+* Add 'net rpc service' subcommands 'create' and 'delete'.
+
+
+o   Jelmer Vernooij jel...@samba.org
+* Make merged build possible.
+* Move common libraries to the shared lib/ directory.
 
 
 ##


-- 
Samba Shared Repository


svn commit: samba-web r1292 - in trunk: .

2009-04-30 Thread kseeger
Author: kseeger
Date: 2009-04-30 09:35:36 + (Thu, 30 Apr 2009)
New Revision: 1292

WebSVN: 
http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=revroot=samba-webrev=1292

Log:
Announce Samba 3.4.0pre1
Karolin
Modified:
   trunk/index.html


Changeset:
Modified: trunk/index.html
===
--- trunk/index.html2009-04-29 07:20:00 UTC (rev 1291)
+++ trunk/index.html2009-04-30 09:35:36 UTC (rev 1292)
@@ -19,6 +19,22 @@
 
 h2Current Release/h2
 
+h430 April 2009/h4
+
+p class=headlineSamba 3.4.0pre1 Available for Download/p
+
+pThe a href=/samba/ftp/pre/samba-3.4.0pre1.tar.gzSamba 3.4.0pre1
+source code/a can be downloaded now. This is the first preview release of
+the Samba 3.4 series. It is emnot/em intended for use on production
+servers. The a href=/samba/ftp/pre/samba-3.4.0pre1.tar.ascGnuPG
+signature is for the emun/emcompressed tarball/a.
+Please see the a href=/samba/ftp/pre/WHATSNEW-3-4-0pre1.txtRelease 
Notes/a
+for more information on this release.
+Precompiled packages will be made available on a volunteer basis and can be
+found in the a href=/samba/ftp/Binary_Packages/Binary_Packages download
+area/a./p
+
+
 h4a name=latest29 April 2009/a/h4
 
 p class=headlineSamba 3.3.4 Available for Download/p



[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha7-1324-g3b666bf

2009-04-30 Thread Volker Lendecke
The branch, master has been updated
   via  3b666bf0f9691e552999b655b2feca71048aa640 (commit)
  from  d22965e2e596c8ad78f5330398d43d96bf564773 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 3b666bf0f9691e552999b655b2feca71048aa640
Author: Volker Lendecke v...@samba.org
Date:   Thu Apr 30 12:24:51 2009 +0200

Fix notify_onelevel: notify is not necessarily enabled

Thanks to Günther Deschner!

Volker

---

Summary of changes:
 source3/smbd/notify_internal.c |4 
 1 files changed, 4 insertions(+), 0 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/smbd/notify_internal.c b/source3/smbd/notify_internal.c
index a42404d..973db7b 100644
--- a/source3/smbd/notify_internal.c
+++ b/source3/smbd/notify_internal.c
@@ -786,6 +786,10 @@ void notify_onelevel(struct notify_context *notify, 
uint32_t action,
bool have_dead_entries = false;
int i;
 
+   if (notify == NULL) {
+   return;
+   }
+
array = talloc_zero(talloc_tos(), struct notify_entry_array);
if (array == NULL) {
return;


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha7-1323-gd22965e

2009-04-30 Thread Günther Deschner
The branch, master has been updated
   via  d22965e2e596c8ad78f5330398d43d96bf564773 (commit)
   via  233bfb25c9443688f74c506348b0a7b34489e1d1 (commit)
   via  a2a155bee59c7e849a492933d1ea5769e409bac5 (commit)
  from  370e7209dbafce147a5e9f283d9dcc53c72bce99 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit d22965e2e596c8ad78f5330398d43d96bf564773
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 11:19:42 2009 +0200

s3-spoolss: avoid referring to uid 0 in spoolss server (use 
sec_initial_uid() instead).

Guenther

commit 233bfb25c9443688f74c506348b0a7b34489e1d1
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 01:25:23 2009 +0200

s3-printing: use move_driver_file_to_download_area() to avoid code 
duplication.

Guenther

commit a2a155bee59c7e849a492933d1ea5769e409bac5
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 01:07:31 2009 +0200

s3-printing: add move_driver_file_to_download_area().

Guenther

---

Summary of changes:
 source3/printing/nt_printing.c  |  238 ++-
 source3/rpc_server/srv_spoolss_nt.c |6 +-
 2 files changed, 97 insertions(+), 147 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/printing/nt_printing.c b/source3/printing/nt_printing.c
index cfef4fe..88e210c 100644
--- a/source3/printing/nt_printing.c
+++ b/source3/printing/nt_printing.c
@@ -1802,6 +1802,46 @@ static char* ffmt(unsigned char *c){
 
 /
 /
+
+static WERROR move_driver_file_to_download_area(TALLOC_CTX *mem_ctx,
+   connection_struct *conn,
+   const char *driver_file,
+   const char *architecture,
+   const char *new_dir,
+   uint32_t version)
+{
+   char *old_name = NULL;
+   char *new_name = NULL;
+   SMB_STRUCT_STAT st;
+   NTSTATUS status;
+
+   new_name = talloc_asprintf(mem_ctx, %s/%s,
+  architecture, driver_file);
+   W_ERROR_HAVE_NO_MEMORY(new_name);
+
+   old_name = talloc_asprintf(mem_ctx, %s/%s,
+  new_dir, driver_file);
+   W_ERROR_HAVE_NO_MEMORY(old_name);
+
+   if (version != -1  (version = file_version_is_newer(conn, new_name, 
old_name))  0) {
+
+   new_name = driver_unix_convert(conn, new_name, st);
+   W_ERROR_HAVE_NO_MEMORY(new_name);
+
+   status = copy_file(mem_ctx, conn, new_name, old_name,
+  OPENX_FILE_EXISTS_TRUNCATE |
+  OPENX_FILE_CREATE_IF_NOT_EXIST,
+  0, false);
+   if (!NT_STATUS_IS_OK(status)) {
+   DEBUG(0,(move_driver_file_to_download_area: Unable to 
rename [%s] to [%s]\n,
+   new_name, old_name));
+   return WERR_ACCESS_DENIED;
+   }
+   }
+
+   return WERR_OK;
+}
+
 WERROR move_driver_to_download_area(struct pipes_struct *p,
NT_PRINTER_DRIVER_INFO_LEVEL 
driver_abstract,
uint32 level, WERROR *perr)
@@ -1810,8 +1850,6 @@ WERROR move_driver_to_download_area(struct pipes_struct 
*p,
NT_PRINTER_DRIVER_INFO_LEVEL_3 converted_driver;
const char *architecture;
char *new_dir = NULL;
-   char *old_name = NULL;
-   char *new_name = NULL;
connection_struct *conn = NULL;
NTSTATUS nt_status;
SMB_STRUCT_STAT st;
@@ -1894,143 +1932,74 @@ WERROR move_driver_to_download_area(struct 
pipes_struct *p,
DEBUG(5,(Moving files now !\n));
 
if (driver-driverpath  strlen(driver-driverpath)) {
-   new_name = talloc_asprintf(ctx,
-   %s/%s,
-   architecture,
-   driver-driverpath);
-   if (!new_name) {
-   *perr = WERR_NOMEM;
-   goto err_exit;
-   }
-   old_name = talloc_asprintf(ctx,
-   %s/%s,
-   new_dir,
-   driver-driverpath);
-   if (!old_name) {
-   *perr = WERR_NOMEM;
-   goto err_exit;
-   }
 
-   if (ver != -1  (ver=file_version_is_newer(conn, new_name, 
old_name))  0) {
-  

[SCM] Samba Shared Repository - branch v3-4-test updated - release-4-0-0alpha7-846-g5b9477f

2009-04-30 Thread Volker Lendecke
The branch, v3-4-test has been updated
   via  5b9477f9930d0c6511c70409561c04c5729bcc05 (commit)
  from  b7c4a63d034f8c33b3a4857cae41270bd55e270f (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-test


- Log -
commit 5b9477f9930d0c6511c70409561c04c5729bcc05
Author: Volker Lendecke v...@samba.org
Date:   Thu Apr 30 13:37:19 2009 +0200

Re-import the v3-3 version of str_list_make().

The merged version behaves differently: Domain Users is parsed into two
values, as it does not look at quotes. Samba3 users depend on the ability do
say for example

valid users = domain users

which would not work anymore with the merged version.

Thanks to Björn Jacke for testing this!

Volker

---

Summary of changes:
 source3/lib/util_str.c |   66 ++-
 1 files changed, 59 insertions(+), 7 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/lib/util_str.c b/source3/lib/util_str.c
index b9ccb83..84e8219 100644
--- a/source3/lib/util_str.c
+++ b/source3/lib/util_str.c
@@ -2422,17 +2422,69 @@ char *escape_shell_string(const char *src)
 }
 
 /***
- Wrapper for str_list_make() to restore the s3 behavior.
- In samba 3.2 passing NULL or an empty string returned NULL.
-
- In master, it now returns a list of length 1 with the first string set
- to NULL (an empty list)
+ str_list_make, v3 version. The v4 version does not
+ look at quoted strings with embedded blanks, so
+ do NOT merge this function please!
 ***/
 
+#define S_LIST_ABS 16 /* List Allocation Block Size */
+
 char **str_list_make_v3(TALLOC_CTX *mem_ctx, const char *string, const char 
*sep)
 {
-   if (!string || !*string) {
+   char **list;
+   const char *str;
+   char *s;
+   int num, lsize;
+   char *tok;
+
+   if (!string || !*string)
+   return NULL;
+
+   list = TALLOC_ARRAY(mem_ctx, char *, S_LIST_ABS+1);
+   if (list == NULL) {
+   return NULL;
+   }
+   lsize = S_LIST_ABS;
+
+   s = talloc_strdup(list, string);
+   if (s == NULL) {
+   DEBUG(0,(str_list_make: Unable to allocate memory));
+   TALLOC_FREE(list);
return NULL;
}
-   return str_list_make(mem_ctx, string, sep);
+   if (!sep) sep = LIST_SEP;
+
+   num = 0;
+   str = s;
+
+   while (next_token_talloc(list, str, tok, sep)) {
+
+   if (num == lsize) {
+   char **tmp;
+
+   lsize += S_LIST_ABS;
+
+   tmp = TALLOC_REALLOC_ARRAY(mem_ctx, list, char *,
+  lsize + 1);
+   if (tmp == NULL) {
+   DEBUG(0,(str_list_make: 
+   Unable to allocate memory));
+   TALLOC_FREE(list);
+   return NULL;
+   }
+
+   list = tmp;
+
+   memset (list[num], 0,
+   ((sizeof(char**)) * (S_LIST_ABS +1)));
+   }
+
+   list[num] = tok;
+   num += 1;
+   }
+
+   list[num] = NULL;
+
+   TALLOC_FREE(s);
+   return list;
 }


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha7-1325-gf4fcf2c

2009-04-30 Thread Volker Lendecke
The branch, master has been updated
   via  f4fcf2c1c0f4fbf465afe78e204436ad1a40 (commit)
  from  3b666bf0f9691e552999b655b2feca71048aa640 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit f4fcf2c1c0f4fbf465afe78e204436ad1a40
Author: Volker Lendecke v...@samba.org
Date:   Thu Apr 30 13:37:19 2009 +0200

Re-import the v3-3 version of str_list_make().

The merged version behaves differently: Domain Users is parsed into two
values, as it does not look at quotes. Samba3 users depend on the ability do
say for example

valid users = domain users

which would not work anymore with the merged version.

Thanks to Björn Jacke for testing this!

Volker

---

Summary of changes:
 source3/lib/util_str.c |   66 ++-
 1 files changed, 59 insertions(+), 7 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/lib/util_str.c b/source3/lib/util_str.c
index 6fd477b..3a941f2 100644
--- a/source3/lib/util_str.c
+++ b/source3/lib/util_str.c
@@ -2422,17 +2422,69 @@ char *escape_shell_string(const char *src)
 }
 
 /***
- Wrapper for str_list_make() to restore the s3 behavior.
- In samba 3.2 passing NULL or an empty string returned NULL.
-
- In master, it now returns a list of length 1 with the first string set
- to NULL (an empty list)
+ str_list_make, v3 version. The v4 version does not
+ look at quoted strings with embedded blanks, so
+ do NOT merge this function please!
 ***/
 
+#define S_LIST_ABS 16 /* List Allocation Block Size */
+
 char **str_list_make_v3(TALLOC_CTX *mem_ctx, const char *string, const char 
*sep)
 {
-   if (!string || !*string) {
+   char **list;
+   const char *str;
+   char *s;
+   int num, lsize;
+   char *tok;
+
+   if (!string || !*string)
+   return NULL;
+
+   list = TALLOC_ARRAY(mem_ctx, char *, S_LIST_ABS+1);
+   if (list == NULL) {
+   return NULL;
+   }
+   lsize = S_LIST_ABS;
+
+   s = talloc_strdup(list, string);
+   if (s == NULL) {
+   DEBUG(0,(str_list_make: Unable to allocate memory));
+   TALLOC_FREE(list);
return NULL;
}
-   return str_list_make(mem_ctx, string, sep);
+   if (!sep) sep = LIST_SEP;
+
+   num = 0;
+   str = s;
+
+   while (next_token_talloc(list, str, tok, sep)) {
+
+   if (num == lsize) {
+   char **tmp;
+
+   lsize += S_LIST_ABS;
+
+   tmp = TALLOC_REALLOC_ARRAY(mem_ctx, list, char *,
+  lsize + 1);
+   if (tmp == NULL) {
+   DEBUG(0,(str_list_make: 
+   Unable to allocate memory));
+   TALLOC_FREE(list);
+   return NULL;
+   }
+
+   list = tmp;
+
+   memset (list[num], 0,
+   ((sizeof(char**)) * (S_LIST_ABS +1)));
+   }
+
+   list[num] = tok;
+   num += 1;
+   }
+
+   list[num] = NULL;
+
+   TALLOC_FREE(s);
+   return list;
 }


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - annotated tag release-3-4-0pre1 created - release-3-4-0pre1

2009-04-30 Thread Karolin Seeger
The annotated tag, release-3-4-0pre1 has been created
at  9115911b21d74d13cb2e687aaa9d30c870c5fe81 (tag)
   tagging  21188807b56319b3eca0d410d3859fa5cdbede54 (commit)
  replaces  release-4-0-0alpha7
 tagged by  Karolin Seeger
on  Thu Apr 30 11:17:59 2009 +0200

- Log -
tag release-3-4-0pre1
-BEGIN PGP SIGNATURE-
Version: GnuPG v2.0.9 (GNU/Linux)

iD8DBQBJ+WzzbzORW2Vot+oRAo5XAJ0T2fSC19BMN9LDUvAL6aphur3FZwCfaPgD
1DhctqJrvUJiW2VzfYaSZZ8=
=TcmD
-END PGP SIGNATURE-

Alexander Zagrebin (1):
  Missing break in conversion function prevents tdb password database 
update.

Andrew Bartlett (18):
  Allow 'net vampire' to work without an existing smb.conf
  Don't print the admin password if we don't set one.
  Pull in all the schema information during DRS schema fetch
  Merge branch 'master' of ssh://git.samba.org/data/git/samba into 
abartlet-devel
  Update talloc version so we don't fail on system talloc 1.2.0
  Remove parse_control from header, long after the function was removed
  Merge branch 'master' of ssh://git.samba.org/data/git/samba into 
master-devel
  s3:smbldap Remove smbldap_get_dn
  s3:printing Convert nt_printer_publish_ads() to use talloc better
  s3:libads Make ads_get_dn() take a talloc context
  s3:smbtorture Convert charcnv torture suite to use push_ucs2_talloc()
  s3:kerberos Rework smb_krb5_unparse_name() to take a talloc context
  s3:smbldap convert the easy cases to push_utf8_talloc()
  s3:charcnv Remove unused ucs2_to_unistr2()
  s3:charcnv Remove unused unistr2 functions
  s3:rpc_parse remove unused prs_unistr2()
  s3:charcnv Remove unused unistrcpy() and unistrlen()
  s3:lib Use push_ucs2_talloc() in ms_fnmatch()

Andrew Tridgell (5):
  added a test that triggers a bug in the Samba3 notify code
  fixed a bug in message handling for code the change notify code
  removed leading spaces from embedded ldif
  fixed more embedded spaces in LDIF
  use a base64 encoded password when changing passwords

Andy Kelk (1):
  Add dirsort module

Björn Jacke (22):
  don't hardcode python path
  some shells are picky about ^ without quotes
  make man page (un)install more portable
  use test -f, Solaris /bin/sh doesn't know test -e
  don't rely on shebang's perl path, call our $PERL instead
  fix dubious escape warning of Studio compiler
  use LIB_PATH_VAR in selftest.sh if we have it
  fix configure check by avoiding main(main(...))
  fix some typos
  fix build on old Heimdal based systems
  ѕ3/winbind_pam: fix gcc 4.4 compile warning
  s3:dsgetdcname: use parentheses in if condition to make negation clear
  s3: ifdef sendfile code that's only used in other ifdef'ed sendfile code
  remove non standard way to point to ctdb path
  s3/pam_smbpass: don't link agains KRB5LIBS
  s3/cifs: don't link cifs mount helpers agains popt
  s3/ldbtools: don't neddlessly link against wbinbind libs
  don't set -O twice
  to be portable, use options first, arguments last
  clean up lib64 linking paths the same way as lib
  remove needless rpath stuff for default paths as early as possible
  ѕ3/configure: fix regexp for ld version recognition

Bo Yang (4):
  Initialize the id_map status in idmap_ldap to avoid surprise
  More fix to initialize idmap statuses
  Fix careless mistake in winbindd_setup_sig_usr2_handler
  Fix crash in async_smb.c

Brad Hards (1):
  Update instructions for checking out pidl.

Dan Sledz (3):
  It appears that the first time we see a uid/gid that winbind can't map,
  s3 pdb_wbc_sam: LookupRids should return sAMAccountName, not NT4 names
  s3: Fix a free of an uninitialized variable in winbind_get_sid_aliases

Dave Richards (2):
  s3: Add strict lock/unlock calls to the vfs layer to replace is_locked
  s3 OneFS: Add kernel strict locking support

David Kwan (1):
  s3 onefs: Change error status to NT_ACCESS_DENIED for errors in 
SET_SECURITY_DESC

Derrell Lipman (2):
  [Bug 6228] SMBC_open_ctx failure due to path resolve failure doesn't set 
errno
  Ensure parameter types match format string

Günther Deschner (387):
  s3-spoolss: remove some unused defines and structs.
  spoolss: add spoolss_JobStatus.
  s3-spoolss: job status defines moved to IDL.
  s3: re-run make samba3-idl.
  s3-spoolss: fix search_notify(). sorry...
  spoolss: add spoolss_JobInfo2, JobInfo3 and JobInfo4 (new in vista).
  spoolss: add 2 new SPOOLSS_JOB_CONTROL values.
  s3: re-run make samba3-idl.
  s3-spoolss: add rpccli_spoolss_getjob convenience wrapper.
  s3-spoolss: remove old rpccli_spoolss_getjob.
  s3-rpcclient: use is_valid_policy_hnd before closing handles.
  s3-rpcclient: add getjob spoolss command.
  s3-spoolss: use DSPRINT flags 

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha7-1326-geee446a

2009-04-30 Thread Günther Deschner
The branch, master has been updated
   via  eee446a94841a5df97b3a47c7076ef52fb5ccdcf (commit)
  from  f4fcf2c1c0f4fbf465afe78e204436ad1a40 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit eee446a94841a5df97b3a47c7076ef52fb5ccdcf
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 14:16:01 2009 +0200

s3-nss_wins: Fix unresolved ldb symbols in libnss_wins.so.

The objects for this module should probably be cleaned up once.

Guenther

---

Summary of changes:
 source3/Makefile.in |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/Makefile.in b/source3/Makefile.in
index f765818..8bf29dd 100644
--- a/source3/Makefile.in
+++ b/source3/Makefile.in
@@ -1063,7 +1063,7 @@ SMBFILTER_OBJ = utils/smbfilter.o $(PARAM_OBJ) 
$(LIBSMB_OBJ) $(LDB_OBJ) \
 
 WINBIND_WINS_NSS_OBJ = ../nsswitch/wins.o $(PARAM_OBJ) \
$(LIBSMB_OBJ) $(LIB_NONSMBD_OBJ) $(NSSWINS_OBJ) $(KRBCLIENT_OBJ) \
-   $(LIBNDR_GEN_OBJ0)
+   $(LIBNDR_GEN_OBJ0) $(LDB_OBJ)
 
 PAM_SMBPASS_OBJ_0 = pam_smbpass/pam_smb_auth.o pam_smbpass/pam_smb_passwd.o \
pam_smbpass/pam_smb_acct.o pam_smbpass/support.o


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-4-test updated - release-4-0-0alpha7-850-gd5da80b

2009-04-30 Thread Günther Deschner
The branch, v3-4-test has been updated
   via  d5da80b175b8e7e12070577abdab4f57917727a3 (commit)
   via  6ca91ff2d56f33a96e013cc3ab796ba38aa10dcd (commit)
   via  bbeefe338e654cb0f43281d9dabe77b59fa931d6 (commit)
   via  be680b2aae289cc7e173c4a76802fe09ff7882f6 (commit)
  from  5b9477f9930d0c6511c70409561c04c5729bcc05 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-test


- Log -
commit d5da80b175b8e7e12070577abdab4f57917727a3
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 14:16:01 2009 +0200

s3-nss_wins: Fix unresolved ldb symbols in libnss_wins.so.

The objects for this module should probably be cleaned up once.

Guenther
(cherry picked from commit eee446a94841a5df97b3a47c7076ef52fb5ccdcf)

commit 6ca91ff2d56f33a96e013cc3ab796ba38aa10dcd
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 11:19:42 2009 +0200

s3-spoolss: avoid referring to uid 0 in spoolss server (use 
sec_initial_uid() instead).

Guenther
(cherry picked from commit d22965e2e596c8ad78f5330398d43d96bf564773)

commit bbeefe338e654cb0f43281d9dabe77b59fa931d6
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 01:25:23 2009 +0200

s3-printing: use move_driver_file_to_download_area() to avoid code 
duplication.

Guenther
(cherry picked from commit 233bfb25c9443688f74c506348b0a7b34489e1d1)

commit be680b2aae289cc7e173c4a76802fe09ff7882f6
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 01:07:31 2009 +0200

s3-printing: add move_driver_file_to_download_area().

Guenther
(cherry picked from commit a2a155bee59c7e849a492933d1ea5769e409bac5)

---

Summary of changes:
 source3/Makefile.in |2 +-
 source3/printing/nt_printing.c  |  238 ++-
 source3/rpc_server/srv_spoolss_nt.c |6 +-
 3 files changed, 98 insertions(+), 148 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/Makefile.in b/source3/Makefile.in
index aefc393..0e66f75 100644
--- a/source3/Makefile.in
+++ b/source3/Makefile.in
@@ -1045,7 +1045,7 @@ SMBFILTER_OBJ = utils/smbfilter.o $(PARAM_OBJ) 
$(LIBSMB_OBJ) $(LDB_OBJ) \
 
 WINBIND_WINS_NSS_OBJ = ../nsswitch/wins.o $(PARAM_OBJ) \
$(LIBSMB_OBJ) $(LIB_NONSMBD_OBJ) $(NSSWINS_OBJ) $(KRBCLIENT_OBJ) \
-   $(LIBNDR_GEN_OBJ0)
+   $(LIBNDR_GEN_OBJ0) $(LDB_OBJ)
 
 PAM_SMBPASS_OBJ_0 = pam_smbpass/pam_smb_auth.o pam_smbpass/pam_smb_passwd.o \
pam_smbpass/pam_smb_acct.o pam_smbpass/support.o
diff --git a/source3/printing/nt_printing.c b/source3/printing/nt_printing.c
index d6fead1..a7cca40 100644
--- a/source3/printing/nt_printing.c
+++ b/source3/printing/nt_printing.c
@@ -1802,6 +1802,46 @@ static char* ffmt(unsigned char *c){
 
 /
 /
+
+static WERROR move_driver_file_to_download_area(TALLOC_CTX *mem_ctx,
+   connection_struct *conn,
+   const char *driver_file,
+   const char *architecture,
+   const char *new_dir,
+   uint32_t version)
+{
+   char *old_name = NULL;
+   char *new_name = NULL;
+   SMB_STRUCT_STAT st;
+   NTSTATUS status;
+
+   new_name = talloc_asprintf(mem_ctx, %s/%s,
+  architecture, driver_file);
+   W_ERROR_HAVE_NO_MEMORY(new_name);
+
+   old_name = talloc_asprintf(mem_ctx, %s/%s,
+  new_dir, driver_file);
+   W_ERROR_HAVE_NO_MEMORY(old_name);
+
+   if (version != -1  (version = file_version_is_newer(conn, new_name, 
old_name))  0) {
+
+   new_name = driver_unix_convert(conn, new_name, st);
+   W_ERROR_HAVE_NO_MEMORY(new_name);
+
+   status = copy_file(mem_ctx, conn, new_name, old_name,
+  OPENX_FILE_EXISTS_TRUNCATE |
+  OPENX_FILE_CREATE_IF_NOT_EXIST,
+  0, false);
+   if (!NT_STATUS_IS_OK(status)) {
+   DEBUG(0,(move_driver_file_to_download_area: Unable to 
rename [%s] to [%s]\n,
+   new_name, old_name));
+   return WERR_ACCESS_DENIED;
+   }
+   }
+
+   return WERR_OK;
+}
+
 WERROR move_driver_to_download_area(struct pipes_struct *p,
NT_PRINTER_DRIVER_INFO_LEVEL 
driver_abstract,
uint32 level, WERROR *perr)
@@ -1810,8 +1850,6 @@ WERROR move_driver_to_download_area(struct pipes_struct 

[SCM] CTDB repository - branch 1.0.69 updated - ctdb-1.0.69-16-g87e674f

2009-04-30 Thread Ronnie Sahlberg
The branch, 1.0.69 has been updated
   via  87e674f93728fb20209b6473f07ca323530ddbdc (commit)
   via  478f43bc3c970edc7c8db3e34095774261a48056 (commit)
  from  a63c79318678abe99d2a36fe4465e63eafc008b7 (commit)

http://gitweb.samba.org/?p=sahlberg/ctdb.git;a=shortlog;h=1.0.69


- Log -
commit 87e674f93728fb20209b6473f07ca323530ddbdc
Author: root r...@rcn1.vsofs1.com
Date:   Fri May 1 01:24:27 2009 +1000

new version 1.0.69-5

commit 478f43bc3c970edc7c8db3e34095774261a48056
Author: root r...@rcn1.vsofs1.com
Date:   Fri May 1 01:18:27 2009 +1000

Add a new variable VerifyRecoveryLock which can be used to disable the test 
that the recovery daemon holds the lock properly when performing a recovery

---

Summary of changes:
 include/ctdb_private.h  |1 +
 packaging/RPM/ctdb.spec |8 +++-
 server/ctdb_recover.c   |   15 +++
 server/ctdb_tunables.c  |1 +
 4 files changed, 20 insertions(+), 5 deletions(-)


Changeset truncated at 500 lines:

diff --git a/include/ctdb_private.h b/include/ctdb_private.h
index df194bc..5121cd9 100644
--- a/include/ctdb_private.h
+++ b/include/ctdb_private.h
@@ -118,6 +118,7 @@ struct ctdb_tunable {
uint32_t recd_ping_failcount;
uint32_t log_latency_ms;
uint32_t recovery_drop_all_ips;
+   uint32_t verify_recovery_lock;
 };
 
 /*
diff --git a/packaging/RPM/ctdb.spec b/packaging/RPM/ctdb.spec
index 01d09e0..432a6aa 100644
--- a/packaging/RPM/ctdb.spec
+++ b/packaging/RPM/ctdb.spec
@@ -5,7 +5,7 @@ Vendor: Samba Team
 Packager: Samba Team sa...@samba.org
 Name: ctdb
 Version: 1.0
-Release: 69_4
+Release: 69_5
 Epoch: 0
 License: GNU GPL version 3
 Group: System Environment/Daemons
@@ -121,6 +121,12 @@ fi
 %{_includedir}/ctdb_private.h
 
 %changelog
+* Fri May 1 2009 : Version 1.0.69-5
+ - Add a new variable VerifyRecoveryLock. When set to 0 this will skip
+   the test inside the main where it verifies that the recovery masted does
+   hold the lock to the reclock file while performing a recovery.
+ - Change the timeout for waiting for a reclock child process to terminate to
+   15 seconds and increase the logging of this potentially fatal condition.
 * Sun Apr 26 2009 : Version 1.0.69_4
  - Add TDB_NO_NESTING to the tdb layer to prevent transaction nesting.
  - Make sure that when we start a recovery transaction that this is not a
diff --git a/server/ctdb_recover.c b/server/ctdb_recover.c
index 153f698..c2807b4 100644
--- a/server/ctdb_recover.c
+++ b/server/ctdb_recover.c
@@ -505,7 +505,7 @@ static void ctdb_set_recmode_timeout(struct event_context 
*ev, struct timed_even
   caused by the cluster filesystem being very slow to
   arbitrate locks immediately after a node failure.   
 */
-   DEBUG(DEBUG_NOTICE,(__location__  set_recmode timeout - allowing 
recmode set\n));
+   DEBUG(DEBUG_ERR,(__location__  set_recmode child process hung/timedout 
CFS slow to grant locks? (allowing recmode set anyway)\n));
state-ctdb-recovery_mode = state-recmode;
ctdb_request_control_reply(state-ctdb, state-c, NULL, 0, NULL);
talloc_free(state);
@@ -628,11 +628,17 @@ int32_t ctdb_control_set_recmode(struct ctdb_context 
*ctdb,
state = talloc(ctdb, struct ctdb_set_recmode_state);
CTDB_NO_MEMORY(ctdb, state);
 
+
+   if (ctdb-tunable.verify_recovery_lock == 0) {
+   /* dont need to verify the reclock file */
+   ctdb-recovery_mode = recmode;
+   return 0;
+   }
+
/* For the rest of what needs to be done, we need to do this in
   a child process since 
   1, the call to ctdb_recovery_lock() can block if the cluster
  filesystem is in the process of recovery.
-  2, running of the script may take a while.
*/
ret = pipe(state-fd);
if (ret != 0) {
@@ -653,7 +659,7 @@ int32_t ctdb_control_set_recmode(struct ctdb_context *ctdb,
char cc = 0;
close(state-fd[0]);
 
-   /* we should not be able to get the lock on the nodes list, 
+   /* we should not be able to get the lock on the reclock file, 
  as it should  be held by the recovery master 
*/
if (ctdb_recovery_lock(ctdb, false)) {
@@ -665,6 +671,7 @@ int32_t ctdb_control_set_recmode(struct ctdb_context *ctdb,
/* make sure we die when our parent dies */
while (kill(parent, 0) == 0 || errno != ESRCH) {
sleep(5);
+   write(state-fd[1], cc, 1);
}
_exit(0);
}
@@ -672,7 +679,7 @@ int32_t ctdb_control_set_recmode(struct ctdb_context *ctdb,
 
talloc_set_destructor(state, set_recmode_destructor);
 
-   state-te = event_add_timed(ctdb-ev, state, 

[SCM] CTDB repository - branch master updated - ctdb-1.0.79-14-g329df9e

2009-04-30 Thread Ronnie Sahlberg
The branch, master has been updated
   via  329df9e47e6ca8ab5143985a999e68f37c6d88a5 (commit)
  from  94343309992929a592348c936e09a7b4f8b512c1 (commit)

http://gitweb.samba.org/?p=sahlberg/ctdb.git;a=shortlog;h=master


- Log -
commit 329df9e47e6ca8ab5143985a999e68f37c6d88a5
Author: root r...@rcn1.vsofs1.com
Date:   Fri May 1 01:18:27 2009 +1000

Add a new variable VerifyRecoveryLock which can be used to disable the test 
that the recovery daemon holds the lock properly when performing a recovery

---

Summary of changes:
 include/ctdb_private.h |1 +
 server/ctdb_recover.c  |   15 +++
 server/ctdb_tunables.c |1 +
 3 files changed, 13 insertions(+), 4 deletions(-)


Changeset truncated at 500 lines:

diff --git a/include/ctdb_private.h b/include/ctdb_private.h
index 2231d33..eac27f7 100644
--- a/include/ctdb_private.h
+++ b/include/ctdb_private.h
@@ -106,6 +106,7 @@ struct ctdb_tunable {
uint32_t recd_ping_failcount;
uint32_t log_latency_ms;
uint32_t recovery_drop_all_ips;
+   uint32_t verify_recovery_lock;
 };
 
 /*
diff --git a/server/ctdb_recover.c b/server/ctdb_recover.c
index f9112a3..374b324 100644
--- a/server/ctdb_recover.c
+++ b/server/ctdb_recover.c
@@ -509,7 +509,7 @@ static void ctdb_set_recmode_timeout(struct event_context 
*ev, struct timed_even
   caused by the cluster filesystem being very slow to
   arbitrate locks immediately after a node failure.   
 */
-   DEBUG(DEBUG_NOTICE,(__location__  set_recmode timeout - allowing 
recmode set\n));
+   DEBUG(DEBUG_ERR,(__location__  set_recmode child process hung/timedout 
CFS slow to grant locks? (allowing recmode set anyway)\n));
state-ctdb-recovery_mode = state-recmode;
ctdb_request_control_reply(state-ctdb, state-c, NULL, 0, NULL);
talloc_free(state);
@@ -632,11 +632,17 @@ int32_t ctdb_control_set_recmode(struct ctdb_context 
*ctdb,
state = talloc(ctdb, struct ctdb_set_recmode_state);
CTDB_NO_MEMORY(ctdb, state);
 
+
+   if (ctdb-tunable.verify_recovery_lock == 0) {
+   /* dont need to verify the reclock file */
+   ctdb-recovery_mode = recmode;
+   return 0;
+   }
+
/* For the rest of what needs to be done, we need to do this in
   a child process since 
   1, the call to ctdb_recovery_lock() can block if the cluster
  filesystem is in the process of recovery.
-  2, running of the script may take a while.
*/
ret = pipe(state-fd);
if (ret != 0) {
@@ -657,7 +663,7 @@ int32_t ctdb_control_set_recmode(struct ctdb_context *ctdb,
char cc = 0;
close(state-fd[0]);
 
-   /* we should not be able to get the lock on the nodes list, 
+   /* we should not be able to get the lock on the reclock file, 
  as it should  be held by the recovery master 
*/
if (ctdb_recovery_lock(ctdb, false)) {
@@ -669,6 +675,7 @@ int32_t ctdb_control_set_recmode(struct ctdb_context *ctdb,
/* make sure we die when our parent dies */
while (kill(parent, 0) == 0 || errno != ESRCH) {
sleep(5);
+   write(state-fd[1], cc, 1);
}
_exit(0);
}
@@ -676,7 +683,7 @@ int32_t ctdb_control_set_recmode(struct ctdb_context *ctdb,
 
talloc_set_destructor(state, set_recmode_destructor);
 
-   state-te = event_add_timed(ctdb-ev, state, timeval_current_ofs(3, 0),
+   state-te = event_add_timed(ctdb-ev, state, timeval_current_ofs(15, 0),
ctdb_set_recmode_timeout, state);
 
state-fde = event_add_fd(ctdb-ev, state, state-fd[0],
diff --git a/server/ctdb_tunables.c b/server/ctdb_tunables.c
index 7fa5e80..bab9aef 100644
--- a/server/ctdb_tunables.c
+++ b/server/ctdb_tunables.c
@@ -54,6 +54,7 @@ static const struct {
{ RecdFailCount,3,  offsetof(struct ctdb_tunable, 
recd_ping_failcount) },
{ LogLatencyMs, 0,  offsetof(struct ctdb_tunable, 
log_latency_ms) },
{ RecoveryDropAllIPs,  60,  offsetof(struct ctdb_tunable, 
recovery_drop_all_ips) },
+   { VerifyRecoveryLock,   1,  offsetof(struct ctdb_tunable, 
verify_recovery_lock) },
 };
 
 /*


-- 
CTDB repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha7-1328-gbaf7850

2009-04-30 Thread Günther Deschner
The branch, master has been updated
   via  baf78506895b8bd50433058ba0f18e1aaf8aeee5 (commit)
   via  af5a71d5280984a7d707e39fb522ecc7e1b71436 (commit)
  from  eee446a94841a5df97b3a47c7076ef52fb5ccdcf (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit baf78506895b8bd50433058ba0f18e1aaf8aeee5
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 16:49:50 2009 +0200

s3-printing: rework move_driver_file_to_download_area() a bit for clarity.

Guenther

commit af5a71d5280984a7d707e39fb522ecc7e1b71436
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 12:30:10 2009 +0200

s3-lsa: use LSA_POLICY_MODE flags in _lsa_GetSystemAccessAccount().

Guenther

---

Summary of changes:
 source3/include/privileges.h|6 ---
 source3/printing/nt_printing.c  |   72 +-
 source3/rpc_server/srv_lsa_nt.c |3 +-
 3 files changed, 42 insertions(+), 39 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/include/privileges.h b/source3/include/privileges.h
index 9a5d928..57d3fc0 100644
--- a/source3/include/privileges.h
+++ b/source3/include/privileges.h
@@ -77,12 +77,6 @@ extern const SE_PRIV se_take_ownership;
 /*
  * These are used in Lsa replies (srv_lsa_nt.c)
  */
-#define PR_NONE0x
-#define PR_LOG_ON_LOCALLY  0x0001
-#define PR_ACCESS_FROM_NETWORK 0x0002
-#define PR_LOG_ON_BATCH_JOB0x0004
-#define PR_LOG_ON_SERVICE  0x0010
-
 
 typedef struct {
uint32 high;
diff --git a/source3/printing/nt_printing.c b/source3/printing/nt_printing.c
index 88e210c..b6e7032 100644
--- a/source3/printing/nt_printing.c
+++ b/source3/printing/nt_printing.c
@@ -1806,8 +1806,8 @@ static char* ffmt(unsigned char *c){
 static WERROR move_driver_file_to_download_area(TALLOC_CTX *mem_ctx,
connection_struct *conn,
const char *driver_file,
-   const char *architecture,
-   const char *new_dir,
+   const char *short_architecture,
+   uint32_t driver_version,
uint32_t version)
 {
char *old_name = NULL;
@@ -1815,26 +1815,30 @@ static WERROR 
move_driver_file_to_download_area(TALLOC_CTX *mem_ctx,
SMB_STRUCT_STAT st;
NTSTATUS status;
 
-   new_name = talloc_asprintf(mem_ctx, %s/%s,
-  architecture, driver_file);
-   W_ERROR_HAVE_NO_MEMORY(new_name);
-
old_name = talloc_asprintf(mem_ctx, %s/%s,
-  new_dir, driver_file);
+  short_architecture, driver_file);
W_ERROR_HAVE_NO_MEMORY(old_name);
 
-   if (version != -1  (version = file_version_is_newer(conn, new_name, 
old_name))  0) {
+   new_name = talloc_asprintf(mem_ctx, %s/%d/%s,
+  short_architecture, driver_version, 
driver_file);
+   W_ERROR_HAVE_NO_MEMORY(new_name);
+
+   if (version != -1  (version = file_version_is_newer(conn, old_name, 
new_name))  0) {
 
-   new_name = driver_unix_convert(conn, new_name, st);
-   W_ERROR_HAVE_NO_MEMORY(new_name);
+   old_name = driver_unix_convert(conn, old_name, st);
+   W_ERROR_HAVE_NO_MEMORY(old_name);
 
-   status = copy_file(mem_ctx, conn, new_name, old_name,
+   DEBUG(10,(move_driver_file_to_download_area: copying '%s' to 
'%s'\n,
+   old_name, new_name));
+
+   status = copy_file(mem_ctx, conn, old_name, new_name,
   OPENX_FILE_EXISTS_TRUNCATE |
   OPENX_FILE_CREATE_IF_NOT_EXIST,
   0, false);
+
if (!NT_STATUS_IS_OK(status)) {
-   DEBUG(0,(move_driver_file_to_download_area: Unable to 
rename [%s] to [%s]\n,
-   new_name, old_name));
+   DEBUG(0,(move_driver_file_to_download_area: Unable to 
rename [%s] to [%s]: %s\n,
+   old_name, new_name, nt_errstr(status)));
return WERR_ACCESS_DENIED;
}
}
@@ -1848,7 +1852,7 @@ WERROR move_driver_to_download_area(struct pipes_struct 
*p,
 {
NT_PRINTER_DRIVER_INFO_LEVEL_3 *driver;
NT_PRINTER_DRIVER_INFO_LEVEL_3 converted_driver;
-   const char *architecture;
+   const char *short_architecture;
char *new_dir = NULL;
connection_struct *conn = NULL;
NTSTATUS nt_status;
@@ -1862,18 +1866,21 @@ WERROR 

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha7-1330-gab4b8c9

2009-04-30 Thread Günther Deschner
The branch, master has been updated
   via  ab4b8c9c0438bc5afca17e3ebf05dde6f98bc0aa (commit)
   via  26b9c9370ce047ecc732082b2b554ffc295ae406 (commit)
  from  baf78506895b8bd50433058ba0f18e1aaf8aeee5 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit ab4b8c9c0438bc5afca17e3ebf05dde6f98bc0aa
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 23:37:26 2009 +0200

s3-netapi: Fix Bug #6309: support remote unjoining of Windows 2003 or 
greater.

Found by David Markey ad...@dmarkey.com. Thanks!

Guenther

commit 26b9c9370ce047ecc732082b2b554ffc295ae406
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 23:36:24 2009 +0200

wkssvcs: add WKSSVC_JOIN_FLAGS_IGNORE_UNSUPPORTED_FLAGS join flag.

Guenther

---

Summary of changes:
 librpc/gen_ndr/ndr_wkssvc.c|1 +
 librpc/gen_ndr/wkssvc.h|1 +
 librpc/idl/wkssvc.idl  |1 +
 .../examples/netdomjoin-gui/netdomjoin-gui.c   |3 ++-
 source3/utils/net_dom.c|3 ++-
 5 files changed, 7 insertions(+), 2 deletions(-)


Changeset truncated at 500 lines:

diff --git a/librpc/gen_ndr/ndr_wkssvc.c b/librpc/gen_ndr/ndr_wkssvc.c
index 050aced..760b4ee 100644
--- a/librpc/gen_ndr/ndr_wkssvc.c
+++ b/librpc/gen_ndr/ndr_wkssvc.c
@@ -5545,6 +5545,7 @@ _PUBLIC_ void ndr_print_wkssvc_joinflags(struct ndr_print 
*ndr, const char *name
 {
ndr_print_uint32(ndr, name, r);
ndr-depth++;
+   ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
WKSSVC_JOIN_FLAGS_IGNORE_UNSUPPORTED_FLAGS, 
WKSSVC_JOIN_FLAGS_IGNORE_UNSUPPORTED_FLAGS, r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
WKSSVC_JOIN_FLAGS_JOIN_WITH_NEW_NAME, WKSSVC_JOIN_FLAGS_JOIN_WITH_NEW_NAME, 
r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
WKSSVC_JOIN_FLAGS_JOIN_DC_ACCOUNT, WKSSVC_JOIN_FLAGS_JOIN_DC_ACCOUNT, r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
WKSSVC_JOIN_FLAGS_DEFER_SPN, WKSSVC_JOIN_FLAGS_DEFER_SPN, r);
diff --git a/librpc/gen_ndr/wkssvc.h b/librpc/gen_ndr/wkssvc.h
index 19aa126..42360a9 100644
--- a/librpc/gen_ndr/wkssvc.h
+++ b/librpc/gen_ndr/wkssvc.h
@@ -458,6 +458,7 @@ struct wkssvc_PasswordBuffer {
 }/* [flag(LIBNDR_PRINT_ARRAY_HEX)] */;
 
 /* bitmap wkssvc_joinflags */
+#define WKSSVC_JOIN_FLAGS_IGNORE_UNSUPPORTED_FLAGS ( 0x1000 )
 #define WKSSVC_JOIN_FLAGS_JOIN_WITH_NEW_NAME ( 0x0400 )
 #define WKSSVC_JOIN_FLAGS_JOIN_DC_ACCOUNT ( 0x0200 )
 #define WKSSVC_JOIN_FLAGS_DEFER_SPN ( 0x0100 )
diff --git a/librpc/idl/wkssvc.idl b/librpc/idl/wkssvc.idl
index 9340990..9e92ed7 100644
--- a/librpc/idl/wkssvc.idl
+++ b/librpc/idl/wkssvc.idl
@@ -659,6 +659,7 @@ import srvsvc.idl, lsa.idl;
} wkssvc_PasswordBuffer;
 
typedef [bitmap32bit] bitmap {
+   WKSSVC_JOIN_FLAGS_IGNORE_UNSUPPORTED_FLAGS = 0x1000,
WKSSVC_JOIN_FLAGS_JOIN_WITH_NEW_NAME= 0x0400,
WKSSVC_JOIN_FLAGS_JOIN_DC_ACCOUNT   = 0x0200,
/* TRUE: defer setting the SPN and dNSHostName until a rename 
operation */
diff --git a/source3/lib/netapi/examples/netdomjoin-gui/netdomjoin-gui.c 
b/source3/lib/netapi/examples/netdomjoin-gui/netdomjoin-gui.c
index 8164b74..629a447 100644
--- a/source3/lib/netapi/examples/netdomjoin-gui/netdomjoin-gui.c
+++ b/source3/lib/netapi/examples/netdomjoin-gui/netdomjoin-gui.c
@@ -655,7 +655,8 @@ static void callback_do_join(GtkWidget *widget,
unjoin_creds_required = TRUE;
join_creds_required = FALSE;
unjoin_flags = NETSETUP_JOIN_DOMAIN |
-  NETSETUP_ACCT_DELETE;
+  NETSETUP_ACCT_DELETE |
+  NETSETUP_IGNORE_UNSUPPORTED_FLAGS;
}
 
if (try_unjoin) {
diff --git a/source3/utils/net_dom.c b/source3/utils/net_dom.c
index 132630d..3bf6a27 100644
--- a/source3/utils/net_dom.c
+++ b/source3/utils/net_dom.c
@@ -38,7 +38,8 @@ static int net_dom_unjoin(struct net_context *c, int argc, 
const char **argv)
const char *account = NULL;
const char *password = NULL;
uint32_t unjoin_flags = NETSETUP_ACCT_DELETE |
-   NETSETUP_JOIN_DOMAIN;
+   NETSETUP_JOIN_DOMAIN |
+   NETSETUP_IGNORE_UNSUPPORTED_FLAGS;
struct cli_state *cli = NULL;
bool do_reboot = false;
NTSTATUS ntstatus;


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-4-test updated - release-4-0-0alpha7-854-g942d47e

2009-04-30 Thread Günther Deschner
The branch, v3-4-test has been updated
   via  942d47e5ed583e29afaa005f9ca6251373db8e2f (commit)
   via  d5c6ff96fd89b87c7331f264044e931b100b3a1a (commit)
   via  492b5cfea364c60376245962a8777e04e31e8392 (commit)
   via  c89fdbed5286806d9a9b0b4a5d35870f7989baf7 (commit)
  from  d5da80b175b8e7e12070577abdab4f57917727a3 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-test


- Log -
commit 942d47e5ed583e29afaa005f9ca6251373db8e2f
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 23:37:26 2009 +0200

s3-netapi: Fix Bug #6309: support remote unjoining of Windows 2003 or 
greater.

Found by David Markey ad...@dmarkey.com. Thanks!

Guenther
(cherry picked from commit ab4b8c9c0438bc5afca17e3ebf05dde6f98bc0aa)

commit d5c6ff96fd89b87c7331f264044e931b100b3a1a
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 23:36:24 2009 +0200

wkssvcs: add WKSSVC_JOIN_FLAGS_IGNORE_UNSUPPORTED_FLAGS join flag.

Guenther
(cherry picked from commit 26b9c9370ce047ecc732082b2b554ffc295ae406)

commit 492b5cfea364c60376245962a8777e04e31e8392
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 16:49:50 2009 +0200

s3-printing: rework move_driver_file_to_download_area() a bit for clarity.

Guenther
(cherry picked from commit baf78506895b8bd50433058ba0f18e1aaf8aeee5)

commit c89fdbed5286806d9a9b0b4a5d35870f7989baf7
Author: Günther Deschner g...@samba.org
Date:   Thu Apr 30 12:30:10 2009 +0200

s3-lsa: use LSA_POLICY_MODE flags in _lsa_GetSystemAccessAccount().

Guenther
(cherry picked from commit af5a71d5280984a7d707e39fb522ecc7e1b71436)

---

Summary of changes:
 librpc/gen_ndr/ndr_wkssvc.c|1 +
 librpc/gen_ndr/wkssvc.h|1 +
 librpc/idl/wkssvc.idl  |1 +
 source3/include/privileges.h   |6 --
 .../examples/netdomjoin-gui/netdomjoin-gui.c   |3 +-
 source3/printing/nt_printing.c |   72 +++-
 source3/rpc_server/srv_lsa_nt.c|3 +-
 source3/utils/net_dom.c|3 +-
 8 files changed, 49 insertions(+), 41 deletions(-)


Changeset truncated at 500 lines:

diff --git a/librpc/gen_ndr/ndr_wkssvc.c b/librpc/gen_ndr/ndr_wkssvc.c
index 050aced..760b4ee 100644
--- a/librpc/gen_ndr/ndr_wkssvc.c
+++ b/librpc/gen_ndr/ndr_wkssvc.c
@@ -5545,6 +5545,7 @@ _PUBLIC_ void ndr_print_wkssvc_joinflags(struct ndr_print 
*ndr, const char *name
 {
ndr_print_uint32(ndr, name, r);
ndr-depth++;
+   ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
WKSSVC_JOIN_FLAGS_IGNORE_UNSUPPORTED_FLAGS, 
WKSSVC_JOIN_FLAGS_IGNORE_UNSUPPORTED_FLAGS, r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
WKSSVC_JOIN_FLAGS_JOIN_WITH_NEW_NAME, WKSSVC_JOIN_FLAGS_JOIN_WITH_NEW_NAME, 
r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
WKSSVC_JOIN_FLAGS_JOIN_DC_ACCOUNT, WKSSVC_JOIN_FLAGS_JOIN_DC_ACCOUNT, r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
WKSSVC_JOIN_FLAGS_DEFER_SPN, WKSSVC_JOIN_FLAGS_DEFER_SPN, r);
diff --git a/librpc/gen_ndr/wkssvc.h b/librpc/gen_ndr/wkssvc.h
index 19aa126..42360a9 100644
--- a/librpc/gen_ndr/wkssvc.h
+++ b/librpc/gen_ndr/wkssvc.h
@@ -458,6 +458,7 @@ struct wkssvc_PasswordBuffer {
 }/* [flag(LIBNDR_PRINT_ARRAY_HEX)] */;
 
 /* bitmap wkssvc_joinflags */
+#define WKSSVC_JOIN_FLAGS_IGNORE_UNSUPPORTED_FLAGS ( 0x1000 )
 #define WKSSVC_JOIN_FLAGS_JOIN_WITH_NEW_NAME ( 0x0400 )
 #define WKSSVC_JOIN_FLAGS_JOIN_DC_ACCOUNT ( 0x0200 )
 #define WKSSVC_JOIN_FLAGS_DEFER_SPN ( 0x0100 )
diff --git a/librpc/idl/wkssvc.idl b/librpc/idl/wkssvc.idl
index 9340990..9e92ed7 100644
--- a/librpc/idl/wkssvc.idl
+++ b/librpc/idl/wkssvc.idl
@@ -659,6 +659,7 @@ import srvsvc.idl, lsa.idl;
} wkssvc_PasswordBuffer;
 
typedef [bitmap32bit] bitmap {
+   WKSSVC_JOIN_FLAGS_IGNORE_UNSUPPORTED_FLAGS = 0x1000,
WKSSVC_JOIN_FLAGS_JOIN_WITH_NEW_NAME= 0x0400,
WKSSVC_JOIN_FLAGS_JOIN_DC_ACCOUNT   = 0x0200,
/* TRUE: defer setting the SPN and dNSHostName until a rename 
operation */
diff --git a/source3/include/privileges.h b/source3/include/privileges.h
index 9a5d928..57d3fc0 100644
--- a/source3/include/privileges.h
+++ b/source3/include/privileges.h
@@ -77,12 +77,6 @@ extern const SE_PRIV se_take_ownership;
 /*
  * These are used in Lsa replies (srv_lsa_nt.c)
  */
-#define PR_NONE0x
-#define PR_LOG_ON_LOCALLY  0x0001
-#define PR_ACCESS_FROM_NETWORK 0x0002
-#define PR_LOG_ON_BATCH_JOB0x0004
-#define PR_LOG_ON_SERVICE  0x0010
-
 
 typedef struct {
uint32 high;
diff --git a/source3/config.guess b/source3/config.guess
index 600580b..cb5b959 100755
--- a/source3/config.guess
+++ b/source3/config.guess
@@ -1,9 +1,10 @@
 #! /bin/sh
 # Attempt to guess a canonical system name.
 #   Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999,
-#   2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+#   2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+#   Free Software Foundation, Inc.
 
-timestamp='2005-09-19'
+timestamp='2009-04-27'
 
 # This file is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
@@ -53,8 +54,8 @@ version=\
 GNU config.guess ($timestamp)
 
 Originally written by Per Bothner.
-Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 
2002, 2003, 2004, 2005
-Free Software Foundation, Inc.
+Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
+2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
@@ -104,7 +105,7 @@ set_cc_for_build='
 trap exitcode=\$?; (rm -f \$tmpfiles 2/dev/null; rmdir \$tmp 2/dev/null)  
exit \$exitcode 0 ;
 trap rm -f \$tmpfiles 2/dev/null; rmdir \$tmp 2/dev/null; exit 1 1 2 13 15 
;
 : ${TMPDIR=/tmp} ;
- { tmp=`(umask 077  mktemp -d -q $TMPDIR/cgXX) 2/dev/null`  test -n 
$tmp  test -d $tmp ; } ||
+ { tmp=`(umask 077  mktemp -d $TMPDIR/cgXX) 2/dev/null`  test -n 
$tmp  test -d $tmp ; } ||
  { test -n $RANDOM  tmp=$TMPDIR/cg$$-$RANDOM  (umask 077  mkdir $tmp) 
; } ||
  { tmp=$TMPDIR/cg-$$  (umask 077  mkdir $tmp)  echo Warning: creating 
insecure temp directory 2 ; } ||
  { echo $me: cannot create a temporary directory in $TMPDIR 2 ; exit 1 ; } 
;
@@ -158,6 +159,7 @@ case 
${UNAME_MACHINE}:${UNAME_SYSTEM}:${UNAME_RELEASE}:${UNAME_VERSION} in
arm*) machine=arm-unknown ;;
sh3el) machine=shl-unknown ;;

[SCM] Samba Shared Repository - branch v3-4-test updated - release-4-0-0alpha7-862-gec02a0c

2009-04-30 Thread Michael Adam
The branch, v3-4-test has been updated
   via  ec02a0c1ceea2afc9324f6f069941deaed38c22d (commit)
   via  c14f81738b64377e978a87681b5e687fa9d4d2a2 (commit)
   via  1b4ab194a9f20ee1392bd54dbb82a6384c4b8b3d (commit)
   via  09192e196bb20e7b8e4203debf9a7e4dc51e1c36 (commit)
   via  c59d97195dc8002b6837e17f5e37be26c7ee5dd3 (commit)
   via  198736e1f17c43853f200435f1c1969e13aed77d (commit)
   via  76a8b17f4f2a48baa6d847648b2d7442b63888bc (commit)
   via  20fcbc85ddb59c7972422471705841cb8595d7ec (commit)
  from  942d47e5ed583e29afaa005f9ca6251373db8e2f (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-test


- Log -
commit ec02a0c1ceea2afc9324f6f069941deaed38c22d
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:15:38 2009 +0200

s3:config.sub: clean some space/tab mixup that git complains about

Michael
(cherry picked from commit 384c1aaa8ee8879b6cc4bc34dfc4d3c9fa11667b)

commit c14f81738b64377e978a87681b5e687fa9d4d2a2
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:10:10 2009 +0200

s3:config.sub: replace old FSF address by the web site url.

Michael
(cherry picked from commit f3308b91d75356a83e99aade7e88d2cd1edc2042)

commit 1b4ab194a9f20ee1392bd54dbb82a6384c4b8b3d
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:09:13 2009 +0200

s3:config.sub: move to GPLv3

Michael
(cherry picked from commit 62a69994f252f7cc98ef12bc39a25a2ee25afb0a)

commit 09192e196bb20e7b8e4203debf9a7e4dc51e1c36
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 00:53:49 2009 +0200

s3:update config.sub from gnu.org (2009-04-17)

as requested in bug #6292.

This is taken from

http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.sub;hb=HEAD

Michael
(cherry picked from commit f81c02c3f31a4700d32aff884254fcd752797be7)

commit c59d97195dc8002b6837e17f5e37be26c7ee5dd3
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:13:30 2009 +0200

s3:config.guess: clean some whitespace/tab mixtures that git complains about

Michael
(cherry picked from commit faaa306c6ae7b00fa5e53321203f072776eefa0a)

commit 198736e1f17c43853f200435f1c1969e13aed77d
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:06:34 2009 +0200

s3:config.guess: replace old FSF address by the web site url.

Michael
(cherry picked from commit d230ac7b322827930de2e1b922cd4b6a597c933f)

commit 76a8b17f4f2a48baa6d847648b2d7442b63888bc
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:04:55 2009 +0200

s3:config.guess: move to GPLv3
(cherry picked from commit fee78294589a02090887233ad112c69d3a5bd383)

commit 20fcbc85ddb59c7972422471705841cb8595d7ec
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 00:52:43 2009 +0200

s3:update config.guess form gnu.org (version 2009-04-27)

as requested in bug #6292.

This is taken from

http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.guess;hb=HEAD

Michael
(cherry picked from commit 1188c78f53fb7d56f4bf61c41fe635b639a311fd)

---

Summary of changes:
 source3/config.guess |  146 ++--
 source3/config.sub   |  199 ++
 2 files changed, 274 insertions(+), 71 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/config.guess b/source3/config.guess
index 600580b..cb5b959 100755
--- a/source3/config.guess
+++ b/source3/config.guess
@@ -1,9 +1,10 @@
 #! /bin/sh
 # Attempt to guess a canonical system name.
 #   Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999,
-#   2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+#   2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+#   Free Software Foundation, Inc.
 
-timestamp='2005-09-19'
+timestamp='2009-04-27'
 
 # This file is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
@@ -53,8 +54,8 @@ version=\
 GNU config.guess ($timestamp)
 
 Originally written by Per Bothner.
-Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 
2002, 2003, 2004, 2005
-Free Software Foundation, Inc.
+Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
+2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
@@ -104,7 +105,7 @@ set_cc_for_build='
 trap exitcode=\$?; (rm -f \$tmpfiles 2/dev/null; rmdir \$tmp 2/dev/null)  
exit \$exitcode 0 ;
 trap rm -f \$tmpfiles 2/dev/null; rmdir \$tmp 2/dev/null; exit 1 1 2 13 15 
;
 : ${TMPDIR=/tmp} ;
- { tmp=`(umask 077  mktemp -d -q $TMPDIR/cgXX) 

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha7-1340-gf3af298

2009-04-30 Thread Jeremy Allison
The branch, master has been updated
   via  f3af298e5b1457ba8661fd0e3f5304ad3175f3ba (commit)
  from  384c1aaa8ee8879b6cc4bc34dfc4d3c9fa11667b (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit f3af298e5b1457ba8661fd0e3f5304ad3175f3ba
Author: Jeremy Allison j...@samba.org
Date:   Thu Apr 30 16:57:42 2009 -0700

Cause cli_close to return an NTSTATUS.
Jeremy.

---

Summary of changes:
 source3/client/client.c   |6 +-
 source3/client/clitar.c   |5 +-
 source3/client/smbspool.c |2 +-
 source3/include/proto.h   |2 +-
 source3/libsmb/clifile.c  |   83 +-
 source3/libsmb/libsmb_file.c  |2 +-
 source3/rpc_client/rpc_transport_np.c |5 +-
 source3/torture/locktest2.c   |2 +-
 source3/torture/mangle_test.c |4 +-
 source3/torture/nbio.c|2 +-
 source3/torture/torture.c |  126 
 source3/utils/net_rpc_printer.c   |8 +-
 12 files changed, 84 insertions(+), 163 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/client/client.c b/source3/client/client.c
index becb066..d3cf08c 100644
--- a/source3/client/client.c
+++ b/source3/client/client.c
@@ -1078,7 +1078,7 @@ static int do_get(const char *rname, const char 
*lname_in, bool reget)
return 1;
}
 
-   if (!cli_close(targetcli, fnum)) {
+   if (!NT_STATUS_IS_OK(cli_close(targetcli, fnum))) {
d_printf(Error %s closing remote file\n,cli_errstr(cli));
rc = 1;
}
@@ -1690,7 +1690,7 @@ static int do_put(const char *rname, const char *lname, 
bool reput)
d_fprintf(stderr, cli_push returned %s\n, nt_errstr(status));
}
 
-   if (!cli_close(targetcli, fnum)) {
+   if (!NT_STATUS_IS_OK(cli_close(targetcli, fnum))) {
d_printf(%s closing remote file %s\n,cli_errstr(cli),rname);
x_fclose(f);
return 1;
@@ -2459,7 +2459,7 @@ static int cmd_close(void)
 
fnum = atoi(buf);
/* We really should use the targetcli here */
-   if (!cli_close(cli, fnum)) {
+   if (!NT_STATUS_IS_OK(cli_close(cli, fnum))) {
d_printf(close %d: %s\n, fnum, cli_errstr(cli));
return 1;
}
diff --git a/source3/client/clitar.c b/source3/client/clitar.c
index 3cc1a25..c7f2819 100644
--- a/source3/client/clitar.c
+++ b/source3/client/clitar.c
@@ -1067,8 +1067,9 @@ static int get_file(file_info2 finfo)
 
/* Now close the file ... */
 
-   if (!cli_close(cli, fnum)) {
-   DEBUG(0, (Error closing remote file\n));
+   if (!NT_STATUS_IS_OK(cli_close(cli, fnum))) {
+   DEBUG(0, (Error %s closing remote file\n,
+   cli_errstr(cli)));
return(False);
}
 
diff --git a/source3/client/smbspool.c b/source3/client/smbspool.c
index 6b099db..07de579 100644
--- a/source3/client/smbspool.c
+++ b/source3/client/smbspool.c
@@ -602,7 +602,7 @@ smb_print(struct cli_state * cli,   /* I - SMB connection */
tbytes += nbytes;
}
 
-   if (!cli_close(cli, fnum)) {
+   if (!NT_STATUS_IS_OK(cli_close(cli, fnum))) {
fprintf(stderr, ERROR: %s closing remote spool %s\n,
cli_errstr(cli), title);
return (get_exit_code(cli, cli_nt_error(cli)));
diff --git a/source3/include/proto.h b/source3/include/proto.h
index f60fc9d..0d52e00 100644
--- a/source3/include/proto.h
+++ b/source3/include/proto.h
@@ -2418,7 +2418,7 @@ struct tevent_req *cli_close_send(TALLOC_CTX *mem_ctx,
  struct event_context *ev,
  struct cli_state *cli, uint16_t fnum);
 NTSTATUS cli_close_recv(struct tevent_req *req);
-bool cli_close(struct cli_state *cli, uint16_t fnum);
+NTSTATUS cli_close(struct cli_state *cli, uint16_t fnum);
 bool cli_ftruncate(struct cli_state *cli, uint16_t fnum, uint64_t size);
 NTSTATUS cli_locktype(struct cli_state *cli, uint16_t fnum,
  uint32_t offset, uint32_t len,
diff --git a/source3/libsmb/clifile.c b/source3/libsmb/clifile.c
index 0573041..abc9391 100644
--- a/source3/libsmb/clifile.c
+++ b/source3/libsmb/clifile.c
@@ -1120,70 +1120,6 @@ int cli_nt_delete_on_close(struct cli_state *cli, 
uint16_t fnum, bool flag)
return true;
 }
 
-/
- Open a file - exposing the full horror of the NT API :-).
- Used in smbtorture.
-/
-
-#if 0
-int cli_nt_create_full(struct cli_state *cli, const char *fname,
-  uint32_t CreatFlags, 

Build status as of Fri May 1 00:00:02 2009

2009-04-30 Thread build
URL: http://build.samba.org/

--- /home/build/master/cache/broken_results.txt.old 2009-04-30 
00:00:41.0 +
+++ /home/build/master/cache/broken_results.txt 2009-05-01 00:00:51.0 
+
@@ -1,22 +1,22 @@
-Build status as of Thu Apr 30 00:00:02 2009
+Build status as of Fri May  1 00:00:02 2009
 
 Build counts:
 Tree Total  Broken Panic 
 build_farm   0  0  0 
-ccache   29 6  0 
+ccache   31 6  0 
 distcc   0  0  0 
-ldb  29 29 0 
-libreplace   29 11 0 
+ldb  31 31 0 
+libreplace   31 12 0 
 lorikeet 0  0  0 
-pidl 18 3  0 
-ppp  12 0  0 
-rsync29 10 0 
+pidl 20 3  0 
+ppp  13 0  0 
+rsync31 12 0 
 samba-docs   0  0  0 
 samba-web0  0  0 
-samba_3_current 27 17 0 
-samba_3_master 28 28 0 
-samba_3_next 28 27 1 
-samba_4_0_test 28 28 2 
-talloc   29 29 0 
-tdb  27 11 0 
+samba_3_current 27 18 0 
+samba_3_master 29 28 2 
+samba_3_next 29 29 1 
+samba_4_0_test 30 29 0 
+talloc   31 31 0 
+tdb  29 11 0 
 


[SCM] CTDB repository - branch master updated - ctdb-1.0.79-16-gbf1b769

2009-04-30 Thread Ronnie Sahlberg
The branch, master has been updated
   via  bf1b76955db6ba00ec64686b53084268573ba6a0 (commit)
   via  72f1c696ee77899f7973878f2568a60d199d4fea (commit)
  from  329df9e47e6ca8ab5143985a999e68f37c6d88a5 (commit)

http://gitweb.samba.org/?p=sahlberg/ctdb.git;a=shortlog;h=master


- Log -
commit bf1b76955db6ba00ec64686b53084268573ba6a0
Author: root r...@rcn1.vsofs1.com
Date:   Fri May 1 12:37:52 2009 +1000

new version 1.0.80

commit 72f1c696ee77899f7973878f2568a60d199d4fea
Author: root r...@rcn1.vsofs1.com
Date:   Fri May 1 12:30:26 2009 +1000

when tracking the ctdb statistics,only decrement num_clients and 
pending_calls IFF the counter is 0

Otherwise there is the chance that we will reset the statistics after the 
counter has been incremented (client connects) to zero   and when the client 
disconnects we decrement it to a negative number.

this is a pure cosmetic patch with no operational impact to ctdb

---

Summary of changes:
 packaging/RPM/ctdb.spec |   10 +-
 server/ctdb_daemon.c|   44 +---
 2 files changed, 42 insertions(+), 12 deletions(-)


Changeset truncated at 500 lines:

diff --git a/packaging/RPM/ctdb.spec b/packaging/RPM/ctdb.spec
index 77bb0ba..bbd467b 100644
--- a/packaging/RPM/ctdb.spec
+++ b/packaging/RPM/ctdb.spec
@@ -4,7 +4,7 @@ Summary: Clustered TDB
 Vendor: Samba Team
 Packager: Samba Team sa...@samba.org
 Name: ctdb
-Version: 1.0.79
+Version: 1.0.80
 Release: 1
 Epoch: 0
 License: GNU GPL version 3
@@ -131,6 +131,14 @@ fi
 %{_libdir}/pkgconfig/ctdb.pc
 
 %changelog
+* Fri May 1 2009 : Version 1.0.80
+ - change init shutdown level to 01 for ctdb so it stops before any of the 
other services
+ - if we can not pull a database from a remote node during recovery, mark that 
node as a culprit so it becomes banned
+ - increase the loglevel when we volunteer to drop all ip addresses after 
beeing in recovery mode for too long. Make this timeout tuneable with 
RecoveryDropAllIPs and have it default to 60 seconds
+ - Add a new flag TDB_NO_NESTING to the tdb layer to prevent nested 
transactions which ctdb does not use and does not expect. Have ctdb set this 
flag to prevent nested transactions from occuring.
+ - dont unconditionally kill off ctdb and restrat it on service ctdb start. 
Fail service ctdb start with an error if ctdb is already running.
+ - Add a new tunable VerifyRecoveryLock that can be set to 0 to prevent the 
main ctdb daemon to verify that the recovery master has locked the reclock file 
correctly before allowing it to set the recovery mode to active.
+ - fix a cosmetic bug with ctdb statistics where certain counters could become 
negative.
 * Wed Apr 8 2009 : Version 1.0.79
  - From Mathieu Parent: add a ctdb pkgconfig file
  - Fix bug 6250
diff --git a/server/ctdb_daemon.c b/server/ctdb_daemon.c
index e730d76..8a3f564 100644
--- a/server/ctdb_daemon.c
+++ b/server/ctdb_daemon.c
@@ -178,7 +178,9 @@ static int ctdb_client_destructor(struct ctdb_client 
*client)
 {
ctdb_takeover_client_destructor_hook(client);
ctdb_reqid_remove(client-ctdb, client-client_id);
-   client-ctdb-statistics.num_clients--;
+   if (client-ctdb-statistics.num_clients) {
+   client-ctdb-statistics.num_clients--;
+   }
 
if (client-num_persistent_updates != 0) {
DEBUG(DEBUG_ERR,(__location__  Client disconnecting with %u 
persistent updates in flight. Starting recovery\n, 
client-num_persistent_updates));
@@ -243,7 +245,9 @@ static void daemon_call_from_client_callback(struct 
ctdb_call_state *state)
res = ctdb_daemon_call_recv(state, dstate-call);
if (res != 0) {
DEBUG(DEBUG_ERR, (__location__  ctdbd_call_recv() returned 
error\n));
-   client-ctdb-statistics.pending_calls--;
+   if (client-ctdb-statistics.pending_calls  0) {
+   client-ctdb-statistics.pending_calls--;
+   }
ctdb_latency(ctdb_db, call_from_client_cb 1, 
client-ctdb-statistics.max_call_latency, dstate-start_time);
return;
}
@@ -253,7 +257,9 @@ static void daemon_call_from_client_callback(struct 
ctdb_call_state *state)
   length, struct ctdb_reply_call);
if (r == NULL) {
DEBUG(DEBUG_ERR, (__location__  Failed to allocate reply_call 
in ctdb daemon\n));
-   client-ctdb-statistics.pending_calls--;
+   if (client-ctdb-statistics.pending_calls  0) {
+   client-ctdb-statistics.pending_calls--;
+   }
ctdb_latency(ctdb_db, call_from_client_cb 2, 
client-ctdb-statistics.max_call_latency, dstate-start_time);
return;
}
@@ -267,7 +273,9 @@ static void daemon_call_from_client_callback(struct
diff --git a/source3/lib/netapi/examples/netdomjoin-gui/netdomjoin-gui.c 

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha7-1331-g8cf78ff

2009-04-30 Thread Jeremy Allison
The branch, master has been updated
   via  8cf78ff55312768d0b454b1d7e0560e04e6296da (commit)
  from  ab4b8c9c0438bc5afca17e3ebf05dde6f98bc0aa (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 8cf78ff55312768d0b454b1d7e0560e04e6296da
Author: Jeremy Allison j...@samba.org
Date:   Thu Apr 30 15:26:43 2009 -0700

Get medieval on our ass about SMB1 file descriptors being 16 bits, not an 
int.
Convert all uses of cli_open(), cli_nt_createXXX to NTSTATUS versions.
This is smaller than it looks, it just fixes a lot of old code.
Next up, ensure all cli_XX functions return NTSTATUS.
Jeremy.

---

Summary of changes:
 source3/client/client.c |   38 ++--
 source3/client/clitar.c |   11 +-
 source3/client/smbspool.c   |5 +-
 source3/include/client.h|2 +-
 source3/include/proto.h |   72 +++---
 source3/libgpo/gpo_filesync.c   |6 +-
 source3/libsmb/clientgen.c  |2 +-
 source3/libsmb/clifile.c|   63 +++--
 source3/libsmb/clioplock.c  |7 +-
 source3/libsmb/cliprint.c   |2 +-
 source3/libsmb/cliquota.c   |   12 +-
 source3/libsmb/clirap.c |6 +-
 source3/libsmb/clireadwrite.c   |   12 +-
 source3/libsmb/clisecdesc.c |4 +-
 source3/libsmb/libsmb_file.c|   16 +-
 source3/libsmb/libsmb_xattr.c   |   21 +-
 source3/torture/denytest.c  |   34 ++-
 source3/torture/locktest.c  |   35 ++--
 source3/torture/locktest2.c |8 +-
 source3/torture/mangle_test.c   |8 +-
 source3/torture/masktest.c  |5 +-
 source3/torture/nbio.c  |   18 +-
 source3/torture/scanner.c   |   22 +-
 source3/torture/torture.c   |  580 ---
 source3/torture/utable.c|   17 +-
 source3/utils/net_rpc.c |7 +-
 source3/utils/net_rpc_printer.c |   31 +-
 source3/utils/smbcacls.c|   33 +--
 source3/utils/smbcquotas.c  |4 +-
 29 files changed, 482 insertions(+), 599 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/client/client.c b/source3/client/client.c
index 7dda981..becb066 100644
--- a/source3/client/client.c
+++ b/source3/client/client.c
@@ -535,12 +535,12 @@ static void display_finfo(file_info *finfo, const char 
*dir)
dir_total += finfo-size;
} else {
char *afname = NULL;
-   int fnum;
+   uint16_t fnum;
 
/* skip if this is . or .. */
if ( strequal(finfo-name,..) || strequal(finfo-name,.) )
return;
    /* create absolute filename for cli_nt_create() FIXME */
afname = talloc_asprintf(ctx,
%s%s%s,
dir,
@@ -554,8 +554,9 @@ static void display_finfo(file_info *finfo, const char *dir)
d_printf( MODE:%s\n, attrib_string(finfo-mode));
d_printf( SIZE:%.0f\n, (double)finfo-size);
d_printf( MTIME:%s, time_to_asc(t));
-   fnum = cli_nt_create(finfo-cli, afname, CREATE_ACCESS_READ);
-   if (fnum == -1) {
+   if (!NT_STATUS_IS_OK(cli_ntcreate(finfo-cli, afname, 0,
+   CREATE_ACCESS_READ, 0, 
FILE_SHARE_READ|FILE_SHARE_WRITE,
+   FILE_OPEN, 0x0, 0x0, fnum))) {
DEBUG( 0, (display_finfo() Failed to open %s: %s\n,
afname,
cli_errstr( finfo-cli)));
@@ -999,7 +1000,8 @@ static NTSTATUS writefile_sink(char *buf, size_t n, void 
*priv)
 static int do_get(const char *rname, const char *lname_in, bool reget)
 {
TALLOC_CTX *ctx = talloc_tos();
-   int handle = 0, fnum;
+   int handle = 0;
+   uint16_t fnum;
bool newhandle = false;
struct timeval tp_start;
uint16 attr;
@@ -1028,9 +1030,7 @@ static int do_get(const char *rname, const char 
*lname_in, bool reget)
 
GetTimeOfDay(tp_start);
 
-   fnum = cli_open(targetcli, targetname, O_RDONLY, DENY_NONE);
-
-   if (fnum == -1) {
+   if (!NT_STATUS_IS_OK(cli_open(targetcli, targetname, O_RDONLY, 
DENY_NONE, fnum))) {
d_printf(%s opening remote file %s\n,cli_errstr(cli),rname);
return 1;
}
@@ -1618,7 +1618,7 @@ static int cmd_allinfo(void)
 static int do_put(const char *rname, const char *lname, bool reput)
 {
TALLOC_CTX *ctx = talloc_tos();
-   int fnum;
+   uint16_t fnum;
XFILE *f;
SMB_OFF_T start = 0;
int rc = 0;
@@ -1636,8 +1636,8 @@ static int do_put(const char *rname, const char *lname, 
bool reput)
GetTimeOfDay(tp_start);
 
if 

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha7-1339-g384c1aa

2009-04-30 Thread Michael Adam
The branch, master has been updated
   via  384c1aaa8ee8879b6cc4bc34dfc4d3c9fa11667b (commit)
   via  f3308b91d75356a83e99aade7e88d2cd1edc2042 (commit)
   via  62a69994f252f7cc98ef12bc39a25a2ee25afb0a (commit)
   via  f81c02c3f31a4700d32aff884254fcd752797be7 (commit)
   via  faaa306c6ae7b00fa5e53321203f072776eefa0a (commit)
   via  d230ac7b322827930de2e1b922cd4b6a597c933f (commit)
   via  fee78294589a02090887233ad112c69d3a5bd383 (commit)
   via  1188c78f53fb7d56f4bf61c41fe635b639a311fd (commit)
  from  8cf78ff55312768d0b454b1d7e0560e04e6296da (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 384c1aaa8ee8879b6cc4bc34dfc4d3c9fa11667b
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:15:38 2009 +0200

s3:config.sub: clean some space/tab mixup that git complains about

Michael

commit f3308b91d75356a83e99aade7e88d2cd1edc2042
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:10:10 2009 +0200

s3:config.sub: replace old FSF address by the web site url.

Michael

commit 62a69994f252f7cc98ef12bc39a25a2ee25afb0a
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:09:13 2009 +0200

s3:config.sub: move to GPLv3

Michael

commit f81c02c3f31a4700d32aff884254fcd752797be7
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 00:53:49 2009 +0200

s3:update config.sub from gnu.org (2009-04-17)

as requested in bug #6292.

This is taken from

http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.sub;hb=HEAD

Michael

commit faaa306c6ae7b00fa5e53321203f072776eefa0a
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:13:30 2009 +0200

s3:config.guess: clean some whitespace/tab mixtures that git complains about

Michael

commit d230ac7b322827930de2e1b922cd4b6a597c933f
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:06:34 2009 +0200

s3:config.guess: replace old FSF address by the web site url.

Michael

commit fee78294589a02090887233ad112c69d3a5bd383
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 01:04:55 2009 +0200

s3:config.guess: move to GPLv3

commit 1188c78f53fb7d56f4bf61c41fe635b639a311fd
Author: Michael Adam ob...@samba.org
Date:   Fri May 1 00:52:43 2009 +0200

s3:update config.guess form gnu.org (version 2009-04-27)

as requested in bug #6292.

This is taken from

http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.guess;hb=HEAD

Michael

---

Summary of changes:
 source3/config.guess |  146 ++--
@@ -535,12 +535,12 @@ static void display_finfo(file_info *finfo, const char 
if ( strequal(finfo-name,..) || strequal(finfo-name,.) )
return;
-   /* create absolute filename for cli_nt_create() FIXME */
+   /* create absolute filename for cli_ntcreate() FIXME */
afname = talloc_asprintf(ctx,
%s%s%s,
 source3/config.sub   |  199 ++
 2 files changed, 274 insertions(+), 71 deletions(-)


Changeset truncated at 500 lines:
